@@ -1,17 +1,14 @@
 package Map::Tube::Kiev;
 
-# Pragmas.
 use strict;
 use warnings;
 use 5.006;
 
-# Modules.
 use File::Share ':all';
 use Moo;
 use namespace::clean;
 
-# Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Get XML.
 has xml => (
@@ -36,6 +33,7 @@ Map::Tube::Kiev - Interface to the Kiev Metro Map.
 =head1 SYNOPSIS
 
  use Map::Tube::Kiev;
+
  my $obj = Map::Tube::Kiev->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
  my $line = $obj->get_line_by_id($line_id);
@@ -57,71 +55,101 @@ For more information about Kiev Map, click L<here|https://en.wikipedia.org/wiki/
 
 =head1 METHODS
 
-=over 8
+=head2 C<new>
 
-=item C<new()>
+ my $obj = Map::Tube::Kiev->new;
 
- Constructor.
+Constructor.
 
-=item C<get_all_routes($from, $to)> [EXPERIMENTAL]
+Returns instance of object.
 
- Get all routes from station to station.
- Returns reference to array with Map::Tube::Route objects.
+=head2 C<get_all_routes> [EXPERIMENTAL]
 
-=item C<get_all_routes($from, $to)> [EXPERIMENTAL]
+ my $routes_ar = $obj->get_all_routes($from, $to);
 
- Get all routes from station to station.
- Returns reference to array with Map::Tube::Route objects.
+Get all routes from station to station.
 
-=item C<get_line_by_id($line_id)>
+Returns reference to array with L<Map::Tube::Route> objects.
 
- Get line object defined by id.
- Returns Map::Tube::Line object.
+=head2 C<get_line_by_id>
 
-=item C<get_lines()>
+ my $line = $obj->get_line_by_id($line_id);
 
- Get lines in metro map.
- Returns reference to unsorted array with Map::Tube::Line objects.
+Get line object defined by id.
 
-=item C<get_node_by_id($station_id)>
+Returns L<Map::Tube::Line> object.
 
- Get station node by id.
- Returns Map::Tube::Node object.
+=head2 C<get_line_by_name>
 
-=item C<get_node_by_name($station_name)>
+ my $line = $obj->get_line_by_name($line_name);
 
- Get station node by name.
- Returns Map::Tube::Node object.
+Get line object defined by name.
 
-=item C<get_shortest_route($from, $to)>
+Returns L<Map::Tube::Line> object.
 
- Get shortest route between $from and $to node names. Node names in $from and $to are case insensitive.
- Returns Map::Tube::Route object.
+=head2 C<get_lines>
 
-=item C<get_stations($line)>
+ my $lines_ar = $obj->get_lines;
 
- Get list of stations for concrete metro line.
- Returns reference to array with Map::Tube::Node objects.
+Get lines in metro map.
 
-=item C<name()>
+Returns reference to unsorted array with L<Map::Tube::Line> objects.
 
- Get metro name.
- Returns string with metro name.
+=head2 C<get_node_by_id>
 
-=item C<xml()>
+ my $station = $obj->get_node_by_id($station_id);
 
- Get XML specification of Kiev metro.
- Returns string with XML.
+Get station node by id.
 
-=back
+Returns L<Map::Tube::Node> object.
+
+=head2 C<get_node_by_name>
+
+ my $station = $obj->get_node_by_name($station_name);
+
+Get station node by name.
+
+Returns L<Map::Tube::Node> object.
+
+=head2 C<get_shortest_route>
+
+ my $route = $obj->get_shortest_route($from, $to);
+
+Get shortest route between C<$from> and C<$to> node names. Node names in C<$from> and C<$to> are case insensitive.
+
+Returns Map::Tube::Route object.
+
+=head2 C<get_stations>
+
+ my $stations_ar = $obj->get_stations($line);
+
+Get list of stations for concrete metro line.
+
+Returns reference to array with L<Map::Tube::Node> objects.
+
+=head2 C<name>
+
+ my $metro_name = $obj->name;
+
+Get metro name.
+
+Returns string with metro name.
+
+=head2 C<xml>
+
+ my $xml_file = $obj->xml;
+
+Get XML specification of Kiev metro.
+
+Returns string with XML.
 
 =head1 EXAMPLE1
 
- # Pragmas.
+=for comment filename=print_kiev_route.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Kiev;
 
@@ -139,12 +167,12 @@ For more information about Kiev Map, click L<here|https://en.wikipedia.org/wiki/
 
 =head1 EXAMPLE2
 
- # Pragmas.
+=for comment filename=print_kiev_def_xml_file.pl
+
  use strict;
  use utf8;
  use warnings;
 
- # Modules.
  use Map::Tube::Kiev;
 
  # Object.
@@ -161,11 +189,11 @@ For more information about Kiev Map, click L<here|https://en.wikipedia.org/wiki/
 
 =head1 EXAMPLE3
 
- # Pragmas.
+=for comment filename=print_kiev_image.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::GraphViz;
  use Map::Tube::GraphViz::Utils qw(node_color_without_label);
  use Map::Tube::Kiev;
@@ -191,19 +219,19 @@ For more information about Kiev Map, click L<here|https://en.wikipedia.org/wiki/
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Kiev/master/images/ex3.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Kiev/master/images/ex3.png" alt="Київський метрополітен" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Kiev/master/images/Kiev.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Kiev/master/images/Kiev.png" alt="Київський метрополітен" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
- # Pragmas.
+=for comment filename=print_kiev_lines.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(encode_utf8);
  use Map::Tube::Kiev;
 
@@ -221,6 +249,56 @@ For more information about Kiev Map, click L<here|https://en.wikipedia.org/wiki/
  # Святошинсько-Броварська лінія
  # Сирецько-Печерська лінія
 
+=head1 EXAMPLE5
+
+=for comment filename=print_kiev_line_stations.pl
+
+ use strict;
+ use warnings;
+
+ use Encode qw(decode_utf8 encode_utf8);
+ use Map::Tube::Kiev;
+
+ # Arguments.
+ if (@ARGV < 1) {
+         print STDERR "Usage: $0 line\n";
+         exit 1;
+ }
+ my $line = decode_utf8($ARGV[0]);
+
+ # Object.
+ my $obj = Map::Tube::Kiev->new;
+
+ # Get stations for line.
+ my $stations_ar = $obj->get_stations($line);
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } @{$stations_ar};
+
+ # Output:
+ # Usage: __PROG__ line
+
+ # Output with 'foo' argument.
+ # Map::Tube::get_stations(): ERROR: Invalid Line Name [foo]. (status: 105) file __PROG__ on line __LINE__
+
+ # Output with 'Сирецько-Печерська лінія' argument.
+ # Сирець
+ # Дорогожичі
+ # Лук'янівська
+ # Золоті ворота
+ # Палац спорту
+ # Кловська
+ # Печерська
+ # Дружби народів
+ # Видубичі
+ # Славутич
+ # Осокорки
+ # Позняки
+ # Харківська
+ # Вирлиця
+ # Бориспільська
+ # Червоний хутір
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -248,22 +326,24 @@ Install the Map::Tube concrete metro modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Map-Tube-Kiev>
+L<https://github.com/michal-josef-spacek/Map-Tube-Kiev>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2015 Michal Špaček
- Artistic License
- BSD 2-Clause License
+© 2014-2023 Michal Josef Špaček
+
+Artistic License
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
